@@ -71,8 +71,11 @@ class _TestResult(TestResult):
 
         self.output_buffer = io.StringIO()
         if self.logger is not None:
-            self.logger_handler_id = self.logger.logger.add(self.output_buffer, level=self.logger._level,
-                                                            colorize=False, format=self.logger._console_format)
+            self.logger_handler_id = self.logger.logger.add(self.output_buffer,
+                                                            level=self.logger._level,
+                                                            colorize=False,
+                                                            format=self.logger._console_format
+                                                            )
 
         stdout_redirector.fp = self.output_buffer
         stderr_redirector.fp = self.output_buffer
