@@ -12,7 +12,7 @@ class YouTest(unittest.TestCase):
 
     def test_get(self):
         """测试get接口 """
-        r = requests.get("https://httpbin.org/get", params={"key":"value"})
+        r = requests.get("https://httpbin.org/get", params={"key":"value"}, hooks={"aa": bbb})
         print(r.json())
 
     def test_post(self):
